﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Reflection.Emit;
using System.Text;
using System.Windows.Forms;

namespace KioskDemo.Custom_Controls
{
    class MenuPanel : System.Windows.Forms.Panel
    {
        public Color backgroundColorNoMouse = Color.FromArgb(255, 0, 0, 0);
        public Color backgroundColorMouseOver = Color.FromArgb(255, 64, 64, 64);
        public Color titleColor = Color.White;
        public float fontSize = 14f;
        private System.Windows.Forms.Label title;

        public MenuPanel():base()
        {
            this.Location = new System.Drawing.Point(0, 0);
            this.Size = new System.Drawing.Size(100, 100);
            this.BackColor = backgroundColorNoMouse;
            this.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;

            //Add event handlers for when the mouse moves in or out of this panel, so we can provide feedback (e.g. change background colour)
            MouseEnter += MenuPanel_MouseEnter;
            MouseLeave += MenuPanel_MouseLeave;

            title = new System.Windows.Forms.Label();
            //Note all of these attributes can be set in the visual designer using the properties.
            //But as we're adding everything in code, we do it here.
            title.Location = new Point(0, 0);   //top left of the panel
            title.Size = new Size(100, 32);
            title.ForeColor = titleColor;
            title.Font = new Font("Arial", fontSize);
            title.TextAlign = ContentAlignment.MiddleCenter;
            Controls.Add(title);

            //Add event handler for when the panel's size gets changed (this is brought on by the MenuGrid resizing things to fit the parent)
            SizeChanged += MenuPanel_SizeChanged;
        }

        private void MenuPanel_SizeChanged(object sender, EventArgs e)
        {
            //Event for when size has changed
            //Means we must update size of all other components
            title.Size = new Size(this.Width, 48);
            
        }

        public void SetTitle(string t)
        {
            title.Text = t;
        }
        public void SetImage(string imageName)
        {
            BackgroundImage = Image.FromFile("../../../Images/Main/" + imageName);
            
        }

        private void MenuPanel_MouseLeave(object sender, EventArgs e)
        {
            BackColor = backgroundColorNoMouse;
        }

        private void MenuPanel_MouseEnter(object sender, EventArgs e)
        {
            BackColor = backgroundColorMouseOver;
        }
    }
}
